@@ -54,6 +54,7 @@ class H2OGAM(H2OGAMParams, H2OCommonParams, H2OSupervisedAlgorithm, FamilyBasedH
                  solver="AUTO",
                  alphaValue=None,
                  lambdaValue=None,
+                 startval=None,
                  lambdaSearch=False,
                  earlyStopping=True,
                  nlambdas=-1,
@@ -99,7 +100,8 @@ class H2OGAM(H2OGAMParams, H2OCommonParams, H2OSupervisedAlgorithm, FamilyBasedH
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.001,
                  customMetricFunc=None,
-                 exportCheckpointsDir=None):
+                 exportCheckpointsDir=None,
+                 aucType="AUTO"):
         Initializer.load_sparkling_jar()
         super(H2OGAM, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OGAM", self.uid)
